is_unspendable

Function is_unspendable 

pub fn is_unspendable<T: VerifiableTransaction>(script: &[u8]) -> bool
Returns whether the passed public key script is unspendable, or guaranteed to fail at execution.

This allows inputs to be pruned instantly when entering the UTXO set.