pub fn is_unspendable<T: VerifiableTransaction>(script: &[u8]) -> boolExpand description
Returns whether the passed public key script is unspendable, or guaranteed to fail at execution.
This allows inputs to be pruned instantly when entering the UTXO set.